@@ -34,6 +34,17 @@ Example:
 import sys
 import os
 
+
+__pitch__ = """
+The ubelt.cmd command is probably the easiest way to execute a command line program from Python. Unlike os.system, subprocess.check_output, and subprocess.call, The syntax for what you want to call is exactly the same no matter what type of configuration you are using.
+
+Either pass the text you would execute on the command line directly or break it up into a list where each item should be considered its own argument. This works regardless of if shell=True or shell=False, so if your command doesn't work with the safer shell=False, you can turn on shell=True without modifying anything else. You can capture output, print it to the screen, or namely --- something few other packages support --- both (via tee=True or verbose>1).
+
+You can also invoke the call via os.system instead of Popen by setting system=True (although this does come with all of the os.system benefits and restrictions).
+
+I'm biased because I wrote it, but subprocess-tee is the only other package I know of that comes close to getting this right. Maybe invoke?
+"""
+
 # import logging
 # logging.basicConfig(
 #     format='[%(asctime)s %(threadName)s %(levelname)s] %(message)s',
@@ -134,6 +145,7 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
         https://github.com/pycontribs/subprocess-tee
         https://github.com/mortoray/shelljob
         https://github.com/netinvent/command_runner
+        https://www.pyinvoke.org/prior-art.html
 
     References:
         .. [SO_11495783] https://stackoverflow.com/questions/11495783/redirect-subprocess-stderr-to-stdout
@@ -186,13 +198,12 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
     Example:
         >>> import ubelt as ub
         >>> from os.path import join, exists
-        >>> fpath1 = join(ub.get_app_cache_dir('ubelt'), 'cmdout1.txt')
-        >>> fpath2 = join(ub.get_app_cache_dir('ubelt'), 'cmdout2.txt')
-        >>> ub.delete(fpath1)
-        >>> ub.delete(fpath2)
+        >>> dpath = ub.Path.appdir('ubelt', 'test').ensuredir()
+        >>> fpath1 = (dpath / 'cmdout1.txt').delete()
+        >>> fpath2 = (dpath / 'cmdout2.txt').delete()
         >>> # Start up two processes that run simultaneously in the background
-        >>> info1 = ub.cmd(('touch', fpath1), detach=True)
-        >>> info2 = ub.cmd('echo writing2 > ' + fpath2, shell=True, detach=True)
+        >>> info1 = ub.cmd(('touch', str(fpath1)), detach=True)
+        >>> info2 = ub.cmd('echo writing2 > ' + str(fpath2), shell=True, detach=True)
         >>> # Detached processes are running in the background
         >>> # We can run other code while we wait for them.
         >>> while not exists(fpath1):
@@ -207,8 +218,8 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
         >>> assert (info1['proc'].wait()) == 0
         >>> assert (info2['proc'].wait()) == 0
         >>> # Check that the process did what we expect
-        >>> assert ub.readfrom(fpath1) == ''
-        >>> assert ub.readfrom(fpath2).strip() == 'writing2'
+        >>> assert fpath1.read_text() == ''
+        >>> assert fpath2.read_text().strip() == 'writing2'
 
     Example:
         >>> # Can also use ub.cmd to call os.system
@@ -232,7 +243,13 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
         command_tup = None
     else:
         import pipes
-        command_tup = command
+        command_parts = []
+        # Allow the user to specify paths as part of the command
+        for part in command:
+            if isinstance(part, os.PathLike):
+                part = os.fspath(part)
+            command_parts.append(part)
+        command_tup = tuple(command_parts)
         command_text = ' '.join(list(map(pipes.quote, command_tup)))
 
     if shell or sys.platform.startswith('win32'):
