@@ -51,6 +51,7 @@ References:
     .. [Pep3106] https://peps.python.org/pep-3106/
     .. [GHDictMap] https://github.com/ulisesojeda/dictionary_map
 """
+import sys
 import operator as op
 import itertools as it
 from collections import OrderedDict
@@ -93,74 +94,12 @@ odict = OrderedDict
 ddict = defaultdict
 
 
-class AutoDict(dict):
-    """
-    An infinitely nested default dict of dicts.
+# Use an ordered dictionary in < 3.7 as the base
 
-    Implementation of Perl's autovivification feature that follows
-    [SO_651794]_.
-
-    SeeAlso:
-        :class:`AutoOrderedDict` - the ordered version
-
-    References:
-        .. [SO_651794] http://stackoverflow.com/questions/651794/init-dict-of-dicts
-
-    Example:
-        >>> import ubelt as ub
-        >>> auto = ub.AutoDict()
-        >>> auto[0][10][100] = None
-        >>> assert str(auto) == '{0: {10: {100: None}}}'
-    """
-    _base = dict
-
-    def __getitem__(self, key):
-        try:
-            # value = super(AutoDict, self).__getitem__(key)
-            value = self._base.__getitem__(self, key)
-        except KeyError:
-            value = self[key] = type(self)()
-        return value
-
-    def to_dict(self):
-        """
-        Recursively casts a AutoDict into a regular dictionary. All nested
-        AutoDict values are also converted.
-
-        Returns:
-            dict: a copy of this dict without autovivification
-
-        Example:
-            >>> from ubelt.util_dict import AutoDict
-            >>> auto = AutoDict()
-            >>> auto[1] = 1
-            >>> auto['n1'] = AutoDict()
-            >>> static = auto.to_dict()
-            >>> assert not isinstance(static, AutoDict)
-            >>> assert not isinstance(static['n1'], AutoDict)
-        """
-        return self._base(
-            (key, (value.to_dict() if isinstance(value, AutoDict) else value))
-            for key, value in self.items())
-
-
-class AutoOrderedDict(OrderedDict, AutoDict):
-    """
-    An infinitely nested default dict of dicts that maintains the ordering
-    of items.
-
-    SeeAlso:
-        :class:`AutoDict` - the unordered version of this class
-
-    Example:
-        >>> import ubelt as ub
-        >>> auto = ub.AutoOrderedDict()
-        >>> auto[0][3] = 3
-        >>> auto[0][2] = 2
-        >>> auto[0][1] = 1
-        >>> assert list(auto[0].values()) == [3, 2, 1]
-    """
-    _base = OrderedDict
+if sys.version_info[0:2] <= (3, 6):  # nocover
+    DictBase = OrderedDict
+else:  # nocover
+    DictBase = dict
 
 
 def dzip(items1, items2, cls=dict):
@@ -1155,6 +1094,24 @@ class SetDict(dict):
 
     """
 
+    def copy(self):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> a = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> b = ub.udict({1: 1, 2: 2, 3: 3})
+            >>> c = a.copy()
+            >>> d = b.copy()
+            >>> assert c is not a
+            >>> assert d is not b
+            >>> assert d == b
+            >>> assert c == a
+            >>> list(map(type, [a, b, c, d]))
+            >>> assert isinstance(c, ub.sdict)
+            >>> assert isinstance(d, ub.udict)
+        """
+        return self.__class__(self)
+
     # We could just use the builtin variant for this specific operation
     def __or__(self, other):
         """ The | union operator """
@@ -1172,9 +1129,172 @@ class SetDict(dict):
         """ The ^ symmetric_difference operator """
         return self.symmetric_difference(other)
 
+    # - reverse versions
+
+    def __ror__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> d1 = self | other
+            >>> d2 = other | self
+            >>> assert isinstance(d1, ub.SetDict), 'should use own type'
+            >>> assert isinstance(d2, ub.SetDict), 'should promote type'
+            >>> print(f'd1={d1}')
+            >>> print(f'd2={d2}')
+            d1={1: 10, 2: 20, 3: 3, 4: 40}
+            d2={1: 1, 2: 2, 4: 40, 3: 3}
+        """
+        return SetDict.union(other, self, cls=self.__class__)
+
+    def __rand__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> d1 = self & other
+            >>> d2 = other & self
+            >>> assert isinstance(d1, ub.SetDict), 'should use own type'
+            >>> assert isinstance(d2, ub.SetDict), 'should promote type'
+            >>> print(f'd1={d1}')
+            >>> print(f'd2={d2}')
+            d1={1: 1, 2: 2}
+            d2={1: 10, 2: 20}
+        """
+        return SetDict.intersection(other, self, cls=self.__class__)
+
+    def __rsub__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> d1 = self - other
+            >>> d2 = other - self
+            >>> assert isinstance(d1, ub.SetDict), 'should use own type'
+            >>> assert isinstance(d2, ub.SetDict), 'should promote type'
+            >>> print(f'd1={d1}')
+            >>> print(f'd2={d2}')
+            d1={3: 3}
+            d2={4: 40}
+        """
+        return SetDict.difference(other, self, cls=self.__class__)
+
+    def __rxor__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> d1 = self ^ other
+            >>> d2 = other ^ self
+            >>> assert isinstance(d1, ub.SetDict), 'should use own type'
+            >>> assert isinstance(d2, ub.SetDict), 'should promote type'
+            >>> print(f'd1={d1}')
+            >>> print(f'd2={d2}')
+            d1={3: 3, 4: 40}
+            d2={4: 40, 3: 3}
+        """
+        return SetDict.symmetric_difference(other, self, cls=self.__class__)
+
+    # - inplace versions
+
+    def __ior__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = orig_ref = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> orig_val = orig_ref.copy()
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> self |= other
+            >>> print(f'self={self}')
+            >>> assert self is orig_ref
+            >>> assert self == (orig_val | other)
+            self={1: 10, 2: 20, 3: 3, 4: 40}
+        """
+        self.update(other)
+        return self
+
+    def __iand__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = orig_ref = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> orig_val = orig_ref.copy()
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> self &= other
+            >>> print(f'self={self}')
+            >>> assert self is orig_ref
+            >>> assert self == (orig_val & other)
+            self={1: 1, 2: 2}
+        """
+        result = self.intersection(other)
+        self.clear()
+        self.update(result)
+        return self
+
+    def __isub__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = orig_ref = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> orig_val = orig_ref.copy()
+            >>> other = {1: 10, 2:20}
+            >>> self -= other
+            >>> print(f'self={self}')
+            >>> assert self is orig_ref
+            >>> assert self == (orig_val - other)
+            self={3: 3}
+
+            >>> import ubelt as ub
+            >>> self = orig_ref = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> orig_val = orig_ref.copy()
+            >>> other = [1]
+            >>> self -= other
+            >>> print(f'self={self}')
+            >>> assert self is orig_ref
+            >>> assert self == (orig_val - other)
+            self={2: 2, 3: 3}
+
+            >>> import ubelt as ub
+            >>> self = orig_ref = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> orig_val = orig_ref.copy()
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> self -= other
+            >>> print(f'self={self}')
+            >>> assert self is orig_ref
+            >>> assert self == (orig_val - other)
+        """
+        result = self.difference(other)
+        self.clear()
+        self.update(result)
+        # common = UDict.intersection(self, other)
+        # for k in common:
+        #     self.pop(k, None)
+        return self
+
+    def __ixor__(self, other):
+        """
+        Example:
+            >>> import ubelt as ub
+            >>> self = orig_ref = ub.sdict({1: 1, 2: 2, 3: 3})
+            >>> orig_val = orig_ref.copy()
+            >>> other = {1: 10, 2:20, 4: 40}
+            >>> self ^= other
+            >>> print(f'self={self}')
+            >>> assert self is orig_ref
+            >>> assert self == (orig_val ^ other)
+        """
+        result = self.symmetric_difference(other)
+        self.clear()
+        self.update(result)
+        return self
+
     ### Main set operations
 
-    def union(self, *others):
+    def union(self, *others, cls=None):
         """
         Return the key-wise union of two or more dictionaries.
 
@@ -1189,6 +1309,9 @@ class SetDict(dict):
                 method. (i.e. it must return an iterable of 2-tuples where the
                 first item is hashable.)
 
+            cls (type):
+                the desired return dictionary type.
+
         Returns:
             dict : whatever the dictionary type of the first argument is
 
@@ -1206,12 +1329,12 @@ class SetDict(dict):
             >>> print(ub.repr2(res, sort=1, nl=0, si=1))
             {0: B_a, 2: C_c, 3: C_d, 4: B_e, 5: A_f, 7: B_h, 8: C_i, 9: D_j, 10: D_k, 11: D_l}
         """
-        cls = self.__class__
+        cls = cls or self.__class__
         args = it.chain([self], others)
         new = cls(it.chain.from_iterable(d.items() for d in args))
         return new
 
-    def intersection(self, *others):
+    def intersection(self, *others, cls=None):
         """
         Return the key-wise intersection of two or more dictionaries.
 
@@ -1225,6 +1348,9 @@ class SetDict(dict):
             *others : other dictionary or set like objects that can
                 be coerced into a set of keys.
 
+            cls (type):
+                the desired return dictionary type.
+
         Returns:
             dict : whatever the dictionary type of the first argument is
 
@@ -1242,14 +1368,14 @@ class SetDict(dict):
             >>> print(ub.repr2(res, sort=1, nl=0, si=1))
             {}
         """
-        cls = self.__class__
+        cls = cls or self.__class__
         isect_keys = set(self.keys())
         for v in others:
             isect_keys.intersection_update(v)
         new = cls((k, self[k]) for k in self if k in isect_keys)
         return new
 
-    def difference(self, *others):
+    def difference(self, *others, cls=None):
         """
         Return the key-wise difference between this dictionary and one or
         more other dictionary / keys.
@@ -1265,6 +1391,9 @@ class SetDict(dict):
             *others : other dictionary or set like objects that can
                 be coerced into a set of keys.
 
+            cls (type):
+                the desired return dictionary type.
+
         Returns:
             dict : whatever the dictionary type of the first argument is
 
@@ -1282,7 +1411,7 @@ class SetDict(dict):
             >>> print(ub.repr2(res, sort=1, nl=0, si=1))
             {5: A_f}
         """
-        cls = self.__class__
+        cls = cls or self.__class__
         other_keys = set()
         for v in others:
             other_keys.update(v)
@@ -1290,7 +1419,7 @@ class SetDict(dict):
         new = cls((k, self[k]) for k in self.keys() if k not in other_keys)
         return new
 
-    def symmetric_difference(self, *others):
+    def symmetric_difference(self, *others, cls=None):
         """
         Return the key-wise symmetric difference between this dictionary and
         one or more other dictionaries.
@@ -1307,6 +1436,9 @@ class SetDict(dict):
             *others : other dictionary or set like objects that can
                 be coerced into a set of keys.
 
+            cls (type):
+                the desired return dictionary type.
+
         Returns:
             dict : whatever the dictionary type of the first argument is
 
@@ -1328,25 +1460,14 @@ class SetDict(dict):
             >>> print(ub.repr2(res, sort=1, nl=0, si=1))
             {0: B_a, 2: C_c, 4: B_e, 5: A_f, 8: C_i, 9: D_j, 10: D_k, 11: D_l}
         """
-        new = self.copy()
+        cls = cls or self.__class__
+        new = cls(self)  # shallow copy
         for d in others:
             for k, v in d.items():
                 if k in new:
                     new.pop(k)
                 else:
                     new[k] = v
-        # Original implementation, not sure which is best, previous one
-        # probably uses less memory.
-        # from collections import defaultdict
-        # cls = self.__class__
-        # accum_count = defaultdict(lambda: 0)
-        # accum_refs = {}
-        # for d in it.chain([self], others):
-        #     for k in d.keys():
-        #         accum_count[k] += 1
-        #         accum_refs[k] = d
-        # new = cls((k, accum_refs[k][k]) for k, count in accum_count.items()
-        #           if count % 2 == 1)
         return new
 
 
@@ -1431,17 +1552,21 @@ class UDict(SetDict):
         Raises:
             KeyError : if a key does not exist and default is not specified
 
+        SeeAlso:
+            :func:`ubelt.util_dict.dict_subset`
+            :func:`ubelt.UDict.take`
+
         Example:
             >>> import ubelt as ub
             >>> a = ub.udict({k: 'A_' + chr(97 + k) for k in [2, 3, 5, 7]})
             >>> s = a.subdict({2, 5})
-            >>> print('s = {}'.format(ub.repr2(s, nl=0)))
+            >>> print('s = {}'.format(ub.repr2(s, nl=0, sort=1)))
             s = {2: 'A_c', 5: 'A_f'}
             >>> import pytest
             >>> with pytest.raises(KeyError):
             >>>     s = a.subdict({2, 5, 100})
             >>> s = a.subdict({2, 5, 100}, default='DEF')
-            >>> print('s = {}'.format(ub.repr2(s, nl=0)))
+            >>> print('s = {}'.format(ub.repr2(s, nl=0, sort=1)))
             s = {2: 'A_c', 5: 'A_f', 100: 'DEF'}
         """
         cls = self.__class__
@@ -1451,6 +1576,48 @@ class UDict(SetDict):
             new = cls([(k, self.get(k, default)) for k in keys])
         return new
 
+    def take(self, keys, default=NoParam):
+        """
+        Get values of an iterable of keys.
+
+        Args:
+            self (Dict[KT, VT]): dictionary or the implicit instance
+
+            keys (Iterable[KT]): keys to take from ``self``
+
+            default (Optional[object] | NoParamType):
+                if specified uses default if keys are missing.
+
+        Yields:
+            VT: a selected value within the dictionary
+
+        Raises:
+            KeyError : if a key does not exist and default is not specified
+
+        SeeAlso:
+            :func:`ubelt.util_list.take`
+            :func:`ubelt.UDict.subdict`
+
+        Example:
+            >>> import ubelt as ub
+            >>> a = ub.udict({k: 'A_' + chr(97 + k) for k in [2, 3, 5, 7]})
+            >>> s = list(a.take({2, 5}))
+            >>> print('s = {}'.format(ub.repr2(s, nl=0, sort=1)))
+            s = ['A_c', 'A_f']
+            >>> import pytest
+            >>> with pytest.raises(KeyError):
+            >>>     s = a.subdict({2, 5, 100})
+            >>> s = list(a.take({2, 5, 100}, default='DEF'))
+            >>> print('s = {}'.format(ub.repr2(s, nl=0, sort=1)))
+            s = ['A_c', 'A_f', 'DEF']
+        """
+        if default is NoParam:
+            for k in keys:
+                yield self[k]
+        else:
+            for k in keys:
+                yield self.get(k, default)
+
     def invert(self, unique_vals=True):
         """
         Swaps the keys and values in a dictionary.
@@ -1621,4 +1788,79 @@ class UDict(SetDict):
         return ub.peek(self.values(), default=default)
 
 
+class AutoDict(UDict):
+    """
+    An infinitely nested default dict of dicts.
+
+    Implementation of Perl's autovivification feature that follows
+    [SO_651794]_.
+
+    References:
+        .. [SO_651794] http://stackoverflow.com/questions/651794/init-dict-of-dicts
+
+    Example:
+        >>> import ubelt as ub
+        >>> auto = ub.AutoDict()
+        >>> auto[0][10][100] = None
+        >>> assert str(auto) == '{0: {10: {100: None}}}'
+    """
+    _base = UDict
+
+    def __getitem__(self, key):
+        try:
+            # value = super(AutoDict, self).__getitem__(key)
+            value = self._base.__getitem__(self, key)
+        except KeyError:
+            value = self[key] = self.__class__()
+        return value
+
+    def to_dict(self):
+        """
+        Recursively casts a AutoDict into a regular dictionary. All directly
+        nested AutoDict values are also converted.
+
+        This effectively de-defaults the structure.
+
+        Returns:
+            dict: a copy of this dict without autovivification
+
+        Example:
+            >>> import ubelt as ub
+            >>> auto = ub.AutoDict()
+            >>> auto[1] = 1
+            >>> auto['n1'] = ub.AutoDict()
+            >>> static = auto.to_dict()
+            >>> assert not isinstance(static, ub.AutoDict)
+            >>> assert not isinstance(static['n1'], ub.AutoDict)
+
+        Example:
+            >>> import ubelt as ub
+            >>> auto = ub.AutoOrderedDict()
+            >>> auto[0][3] = 3
+            >>> auto[0][2] = 2
+            >>> auto[0][1] = 1
+            >>> assert list(auto[0].values()) == [3, 2, 1]
+        """
+        return self._base(
+            (key, (value.to_dict() if isinstance(value, AutoDict) else value))
+            for key, value in self.items())
+
+
+# DEPRECATED. This is no longer needed. AutoDict is always ordered
+
+if sys.version_info[0:2] <= (3, 6):  # nocover
+    AutoOrderedDict = AutoDict
+else:  # nocover
+    AutoOrderedDict = AutoDict
+    # def __getattr__(key):
+    #     if key == 'AutoOrderedDict':
+    #         import ubelt as ub
+    #         ub.schedule_deprecation(
+    #             modname='ubelt', name='AutoOrderedDict', type='class',
+    #             migration='use AutoDict instead',
+    #             deprecate='1.2.0', error='2.0.0', remove='2.1.0')
+    #         return AutoDict
+    #     else:
+    #         raise AttributeError(key)
+
 udict = UDict
