@@ -49,6 +49,8 @@ repr2 function itself.
 >>> print(ub.repr2({1: float('nan'), 2: float('inf'), 3: 3.0}, nl=0))
 """
 import collections
+from ubelt import util_str
+from ubelt import util_list
 
 __all__ = ['repr2', 'FormatterExtensions']
 
@@ -115,7 +117,7 @@ def repr2(data, **kwargs):
                 default kvsep is modified to ``'='``
                 default itemsep is modified to  ``''``
                 default nobraces is modified to ``1``.
-                default nl is modified to ``0``.
+                default newlines is modified to ``0``.
                 default strkeys to ``True``
                 default strvals to ``True``
 
@@ -126,7 +128,9 @@ def repr2(data, **kwargs):
             separator between keys and values
 
         itemsep (str, default=' '):
-            separator between items
+            separator between items. This separator is placed after commas,
+            which are currently not configurable. This may be modified in the
+            future.
 
         sort (bool | callable, default=None):
             if None, then sort unordered collections, but keep the ordering of
@@ -811,13 +815,12 @@ def _join_itemstrs(itemstrs, itemsep, newlines, _leaf_info, nobraces,
             if compact_brace:
                 # Why must we modify the indentation below and not here?
                 # prefix = ''
-                # rest = [ub.indent(s, prefix) for s in itemstrs[1:]]
+                # rest = [util_str.indent(s, prefix) for s in itemstrs[1:]]
                 # indented = itemstrs[0:1] + rest
                 indented = itemstrs
             else:
-                import ubelt as ub
                 prefix = ' ' * 4
-                indented = [ub.indent(s, prefix) for s in itemstrs]
+                indented = [util_str.indent(s, prefix) for s in itemstrs]
 
             if align:
                 indented = _align_lines(indented, character=align)
@@ -967,14 +970,13 @@ def _sort_itemstrs(items, itemstrs, key=None):
     """
     # First try to sort items by their normal values
     # If that does not work, then sort by their string values
-    import ubelt as ub
     try:
         # Set ordering is not unique. Sort by strings values instead.
         if len(items) > 0 and isinstance(items[0], (set, frozenset)):
             raise TypeError
-        sortx = ub.argsort(items, key=key)
+        sortx = util_list.argsort(items, key=key)
     except TypeError:
-        sortx = ub.argsort(itemstrs, key=key)
+        sortx = util_list.argsort(itemstrs, key=key)
     itemstrs = [itemstrs[x] for x in sortx]
     return itemstrs
 
